==> heptapod-rails-0.22.0.tar.gz: heptapod-rails-0.22.0/app/mailers/emails/pipelines.rb <==
# frozen_string_literal: true

module Emails
  module Pipelines
    def pipeline_success_email(pipeline, recipients)
      pipeline_mail(pipeline, recipients, 'Successful')
    end

    def pipeline_failed_email(pipeline, recipients)
      pipeline_mail(pipeline, recipients, 'Failed')
    end

    def pipeline_fixed_email(pipeline, recipients)
      pipeline_mail(pipeline, recipients, 'Fixed')
    end

    private

    def pipeline_mail(pipeline, recipients, status)
      @project = pipeline.project
      @pipeline = pipeline

      @merge_request = if pipeline.merge_request?
                         pipeline.merge_request
                       else
                         pipeline.merge_requests_as_head_pipeline.first
                       end

      add_headers

      # We use bcc here because we don't want to generate these emails for a
      # thousand times. This could be potentially expensive in a loop, and
      # recipients would contain all project watchers so it could be a lot.
      mail_args = { bcc: recipients, subject: pipeline_subject(status) }

      if !recipients.nil? && recipients.length == 1
        # "Pipeline emails" integration can be used to send notifications of
        # failure to mailing-lists. By default, GitLab sends those mails
        # without a `To:` header, which trips anti-spam filters for mailing
        # lists. This is not a great solution, but a temporary one. A better
        # solution is to add a boolean to the UI to say "these emails should
        # have a `To:` header".
        mail_args[:to] = recipients[0]
        mail_args.delete(:bcc) # avoid needless source of confusion
      end

      mail(**mail_args) do |format|
        format.html { render layout: 'mailer' }
        format.text { render layout: 'mailer' }
      end
    end

    def add_headers
      add_project_headers
      add_pipeline_headers
    end

    def add_pipeline_headers
      headers['X-GitLab-Pipeline-Id'] = @pipeline.id
      headers['X-GitLab-Pipeline-Ref'] = @pipeline.ref
      headers['X-GitLab-Pipeline-Status'] = @pipeline.status
    end

    def pipeline_subject(status)
      subject = []

      subject << "#{status} pipeline for #{@pipeline.source_ref}"
      subject << @project.name if @project
      subject << @pipeline.short_sha

      subject.join(' | ')
    end
  end
end

==> heptapod-rails-0.26.0.tar.gz: heptapod-rails-0.26.0/app/mailers/emails/pipelines.rb <==
# frozen_string_literal: true

module Emails
  module Pipelines
    def pipeline_success_email(pipeline, recipients)
      pipeline_mail(pipeline, recipients, 'Successful')
    end

    def pipeline_failed_email(pipeline, recipients)
      pipeline_mail(pipeline, recipients, 'Failed')
    end

    def pipeline_fixed_email(pipeline, recipients)
      pipeline_mail(pipeline, recipients, 'Fixed')
    end

    private

    def pipeline_mail(pipeline, recipients, status)
      @project = pipeline.project
      @pipeline = pipeline

      @merge_request = if pipeline.merge_request?
                         pipeline.merge_request
                       else
                         pipeline.merge_requests_as_head_pipeline.first
                       end

      add_headers

      # We use bcc here because we don't want to generate these emails for a
      # thousand times. This could be potentially expensive in a loop, and
      # recipients would contain all project watchers so it could be a lot.
      mail_args = { bcc: recipients, subject: subject(pipeline_subject(status)) }

      if !recipients.nil? && recipients.length == 1
        # "Pipeline emails" integration can be used to send notifications of
        # failure to mailing-lists. By default, GitLab sends those mails
        # without a `To:` header, which trips anti-spam filters for mailing
        # lists. This is not a great solution, but a temporary one. A better
        # solution is to add a boolean to the UI to say "these emails should
        # have a `To:` header".
        mail_args[:to] = recipients[0]
        mail_args.delete(:bcc) # avoid needless source of confusion
      end

      mail(**mail_args) do |format|
        format.html { render layout: 'mailer' }
        format.text { render layout: 'mailer' }
      end
    end

    def add_headers
      add_project_headers
      add_pipeline_headers
    end

    def add_pipeline_headers
      headers['X-GitLab-Pipeline-Id'] = @pipeline.id
      headers['X-GitLab-Pipeline-Ref'] = @pipeline.ref
      headers['X-GitLab-Pipeline-Status'] = @pipeline.status
    end

    def pipeline_subject(status)
      subject = []

      subject << "#{status} pipeline for #{@pipeline.source_ref}"
      subject << @pipeline.short_sha

      subject.join(' | ')
    end
  end
end
